@@ -109,7 +109,7 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
 
     def __init__(
         self,
-        executable_path="chromedriver",
+        executable_path="./chromedriver",
         port=0,
         options=None,
         service_args=None,
@@ -200,7 +200,7 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
             capabilities = self.options.to_capabilities()
         super().start_session(capabilities, browser_profile)
 
-    def get_in(self, url: str, delay=1, factor=1):
+    def get_in(self, url: str, delay=2.5, factor=1):
         """
         :param url: str
         :param delay: int
